@@ -224,6 +224,7 @@
 #define __NR_tgkill	268
 #define __NR_utimes	269
 #define __NR_fadvise64_64	270
+#define __NR_arm_fadvise64_64	270
 #define __NR_pciconfig_iobase	271
 #define __NR_pciconfig_read	272
 #define __NR_pciconfig_write	273
@@ -295,6 +296,7 @@
 #define __NR_get_robust_list	339
 #define __NR_splice	340
 #define __NR_sync_file_range2	341
+#define __NR_arm_sync_file_range	341
 #define __NR_tee	342
 #define __NR_vmsplice	343
 #define __NR_move_pages	344
@@ -341,6 +343,16 @@
 #define __NR_memfd_create	385
 #define __NR_bpf	386
 #define __NR_execveat	387
+#define __NR_userfaultfd	388
+#define __NR_membarrier		389
+#define __NR_mlock2		390
+#define __NR_copy_file_range	391
+#define __NR_preadv2	392
+#define __NR_pwritev2	393
+#define __NR_pkey_mprotect	394
+#define __NR_pkey_alloc	395
+#define __NR_pkey_free	396
+#define __NR_statx	397
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -348,8 +360,6 @@
 #define __ARM_NR_usr32		0x0f0004
 #define __ARM_NR_set_tls	0x0f0005
 
-/* Repeated with SYS_ prefix */
-
 #define SYS_restart_syscall	0
 #define SYS_exit	1
 #define SYS_fork	2
@@ -576,6 +586,7 @@
 #define SYS_tgkill	268
 #define SYS_utimes	269
 #define SYS_fadvise64_64	270
+#define SYS_arm_fadvise64_64	270
 #define SYS_pciconfig_iobase	271
 #define SYS_pciconfig_read	272
 #define SYS_pciconfig_write	273
@@ -647,6 +658,7 @@
 #define SYS_get_robust_list	339
 #define SYS_splice	340
 #define SYS_sync_file_range2	341
+#define SYS_arm_sync_file_range	341
 #define SYS_tee	342
 #define SYS_vmsplice	343
 #define SYS_move_pages	344
@@ -693,3 +705,13 @@
 #define SYS_memfd_create	385
 #define SYS_bpf	386
 #define SYS_execveat	387
+#define SYS_userfaultfd	388
+#define SYS_membarrier		389
+#define SYS_mlock2		390
+#define SYS_copy_file_range	391
+#define SYS_preadv2	392
+#define SYS_pwritev2	393
+#define SYS_pkey_mprotect	394
+#define SYS_pkey_alloc	395
+#define SYS_pkey_free	396
+#define SYS_statx	397
